darkhistory.history.reionization — DarkHistory documentation

# darkhistory.history.reionization

Reionization model.

Functions

`alphaA_recomb`(species, T) | Case-A recombination coefficient.
`brem_cooling_rate`(xHII, xHeII, xHeIII, T_m, rs) | Bremsstrahlung cooling rate.
`coll_exc_cooling_rate`(xHII, xHeII, xHeIII, …) | Collisional excitation cooling rate.
`coll_ion_cooling_rate`(xHII, xHeII, xHeIII, …) | Collisional ionization cooling rate.
`coll_ion_rate`(species, T_m) | Collisional ionization rate.
`photoheat_rate`(species) | Photoheating rate.
`photoion_rate`(species) | Photoionization rate.
`recomb_cooling_rate`(xHII, xHeII, xHeIII, T_m, rs) | Recombination cooling rate.

#### Previous topic

darkhistory.history.histools.IonRSInterp

#### Next topic

darkhistory.history.reionization.alphaA_recomb

### This Page

Show Source